@@ -1,5 +1,5 @@
 package Consul;
-$Consul::VERSION = '0.018';
+$Consul::VERSION = '0.019';
 # ABSTRACT: Client library for consul
 
 use namespace::autoclean;
@@ -22,6 +22,8 @@ has ssl => ( is => 'ro', isa => Bool, default => sub { 0 } );
 
 has timeout => ( is => 'ro', isa => Int, default => sub { 15 } );
 
+has token => ( is => 'ro', isa => Str, predicate => '_has_token' );
+
 has _http => ( is => 'lazy', isa => class_type('HTTP::Tiny') );
 sub _build__http { HTTP::Tiny->new(timeout => shift->timeout) };
 
@@ -52,6 +54,10 @@ sub _prep_request {
 
     my $headers = Hash::MultiValue->new;
 
+    if ($self->_has_token()) {
+        $headers->set( 'X-Consul-Token', $self->token() );
+    }
+
     return Consul::Request->new(
         method   => $method,
         url      => $self->_prep_url($path, %uargs),
@@ -259,6 +265,14 @@ method will fail (default: 15).
 
 =item *
 
+C<token>
+
+Consul ACL token.  This is used to set the C<X-Consul-Token> HTTP header.  Typically
+Consul agents are pre-configured with a default ACL token, or ACLs are not enabled
+at all, so this option only needs to be set in certain cases.
+
+=item *
+
 C<request_cb>
 
 A callback to an alternative method to make the actual HTTP request. The
